==> haskell-megaparsec-9.7.0-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 megaparsec
version:              9.7.0
visibility:           public
id:                   megaparsec-9.7.0-EJ90AsoHAMdCjQYvJMoIz4
key:                  megaparsec-9.7.0-EJ90AsoHAMdCjQYvJMoIz4
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that tries to find a nice balance
    between speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  bfc30c59e8ae634b3c45f4286030e56c
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Binary
    Text.Megaparsec.Byte.Lexer Text.Megaparsec.Char
    Text.Megaparsec.Char.Lexer Text.Megaparsec.Debug
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Internal Text.Megaparsec.Pos Text.Megaparsec.State
    Text.Megaparsec.Stream Text.Megaparsec.Unicode

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-megaparsec
hs-libraries:         HSmegaparsec-9.7.0-EJ90AsoHAMdCjQYvJMoIz4
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8vz9c08oERN6HaPlnW3IdE containers-0.6.7
    deepseq-1.4.8.1 mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    scientific-0.3.8.0-JLcC8H5zZSyDPbVdOVmQEk text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-megaparsec-9.7.0-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 megaparsec
version:              9.7.0
visibility:           public
id:                   megaparsec-9.7.0-J7oRvDmmxLP8uuOmkK9aRM
key:                  megaparsec-9.7.0-J7oRvDmmxLP8uuOmkK9aRM
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that tries to find a nice balance
    between speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  4943c256931179edf08b026a1b50f407
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Binary
    Text.Megaparsec.Byte.Lexer Text.Megaparsec.Char
    Text.Megaparsec.Char.Lexer Text.Megaparsec.Debug
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Internal Text.Megaparsec.Pos Text.Megaparsec.State
    Text.Megaparsec.Stream Text.Megaparsec.Unicode

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/megaparsec-9.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-megaparsec
hs-libraries:         HSmegaparsec-9.7.0-J7oRvDmmxLP8uuOmkK9aRM
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-HFTLAepm1u61gRs0sAANH containers-0.6.7
    deepseq-1.4.8.1 mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    scientific-0.3.8.0-CFYO4vxJ7Tde72prrjPHU text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
